# sheepts

[![Build Status](https://travis-ci.org/aliciawyy/sheep.svg?branch=master)](https://travis-ci.org/aliciawyy/sheep)
[![codecov](https://codecov.io/gh/aliciawyy/sheep/branch/master/graph/badge.svg)](https://codecov.io/gh/aliciawyy/sheep)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sheepts.svg)](https://pypi.org/project/sheepts/)
[![Maintainability](https://api.codeclimate.com/v1/badges/3e64e254c33eee6cb21b/maintainability)](https://codeclimate.com/github/aliciawyy/sheep/maintainability)

Light Time Series Toolbox
